Struct actix_web_validator::Path [−][src]
pub struct Path<T> { /* fields omitted */ }Expand description
Extract typed information from the request’s path.
Example
It is possible to extract path information to a specific type that
implements Deserialize trait from serde and Validate trait from validator.
use actix_web::{web, App, Error}; use serde::Deserialize; use actix_web_validator::Path; use validator::Validate; #[derive(Deserialize, Validate)] struct Info { #[validate(length(min = 1))] username: String, } /// extract `Info` from a path using serde async fn index(info: Path<Info>) -> Result<String, Error> { Ok(format!("Welcome {}!", info.username)) } fn main() { let app = App::new().service( web::resource("/{username}/index.html") // <- define path parameters .route(web::get().to(index)) // <- use handler with Path` extractor ); }
Implementations
Deconstruct to an inner value